@@ -4,19 +4,11 @@ use 5.014;
 
 use Data::Object 'Class', 'Doodle::Library';
 
+with 'Doodle::Schema::Helpers';
+
 use Doodle::Table;
 
-our $VERSION = '0.02'; # VERSION
-
-has charset => (
-  is => 'ro',
-  isa => 'Str',
-);
-
-has collation => (
-  is => 'ro',
-  isa => 'Str',
-);
+our $VERSION = '0.03'; # VERSION
 
 has doodle => (
   is => 'ro',
@@ -24,11 +16,6 @@ has doodle => (
   req => 1
 );
 
-has engine => (
-  is => 'ro',
-  isa => 'Str',
-);
-
 has name => (
   is => 'ro',
   isa => 'Str',
@@ -40,6 +27,19 @@ has temporary => (
   isa => 'Bool',
 );
 
+has data => (
+  is => 'ro',
+  isa => 'Data',
+  bld => 'new_data',
+  lzy => 1
+);
+
+# BUILD
+
+fun new_data($self) {
+  return do('hash', {});
+}
+
 # METHODS
 
 method table(Str $name, Any %args) {
@@ -61,7 +61,7 @@ method create(Any %args) {
 method delete(Any %args) {
   $args{schema} = $self;
 
-  my $command = $self->doodle->schema_create(%args);
+  my $command = $self->doodle->schema_delete(%args);
 
   return $command;
 }
