@@ -4,7 +4,7 @@ use 5.014;
 
 use Data::Object 'Role', 'Doodle::Library';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # METHODS
 
@@ -316,6 +316,16 @@ method timestamps_tz() {
   return [$created_at, $updated_at, $deleted_at];
 }
 
+method no_morphs(Str $name) {
+  my $type = "${name}_type";
+  my $fkey = "${name}_fkey";
+
+  my $type_column = $self->string($type)->delete;
+  my $fkey_column = $self->integer($fkey)->delete;
+
+  return [$type_column, $fkey_column];
+}
+
 method no_timestamps() {
   my $created_at = $self->column('created_at')->delete;
   my $updated_at = $self->column('updated_at')->delete;
@@ -806,6 +816,23 @@ Registers columns neccessary for polymorphism and returns the Column object set.
 
 =cut
 
+=head2 no_morphs
+
+  no_morphs(Str $name) : [Command]
+
+Registers a drop for C<{name}_fkey> and C<{name}_type> polymorphic columns and
+returns the Command object set.
+
+=over 4
+
+=item no_morphs example
+
+  my $no_morphs = $self->no_morphs('profile');
+
+=back
+
+=cut
+
 =head2 no_timestamps
 
   no_timestamps() : [Command]
